#importing libraries
import numpy as np
import pandas as pd
import sys
import datawig

def missing(data):

    if data.shape[0]==0:
        return print("empty dataset")
    col_null=data.columns[data.isnull().any()]
    data_out=pd.DataFrame(0,index=np.arange(len(data)),columns=col_null)
    pstatement=[]
    for nul_col in col_null:
        cnull=data[nul_col].isnull()
        cwnull=data[nul_col].notnull()
        imputer=datawig.SimpleImputer(data.columns[data.columns!=nul_col],nul_col,'imputer_model')
        imputer.fit(data[cwnull])
        final=imputer.predict(data[cnull])
        data_out[nul_col]=final[nul_col+'_imputed']
        pstatement.append("number of missing values replaced in "+ str(nul_col) + " is "+ str(final.shape[0]))

data = data.fillna(data_out)
print("\n\n\n")
for i in pstatement:
    print("\n",i)
    return data

def main():
    if len(sys.argv)!=2:
        print("Incorrect parameters.Input format:python <programName> <InputDataFile> <OutputDataFile>")
        exit(1)
    else:
        data=pd.read_csv(sys.argv[1])
        
        missing(data).to_csv(sys.argv[1])

if __name__ == "__main__":
    main()




from distutils.core import setup
setup(
      name = 'srishti-missingvalues-101703562',         # How you named your package folder (MyLib)
      packages = ['srishti-missingvalues-101703562'],   # Chose the same as "name"
      version = '0.1',      # Start with a small number and increase it with every change you make
      license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
      description = 'package for handling missing values',   # Give a short description about your library
      author = 'Srishti',                   # Type in your name
      author_email = 'srishti.1007.sk@gamil.com',      # Type in your E-Mail
      url = 'https://github.com/SrishtiKalra/srishti-missingvalues-101703562',   # Provide either the link to your github or to your website
      download_url = 'https://github.com/SrishtiKalra/srishti-missingvalues-101703562/archive/0.1.tar.gz',    # I explain this later on
      keywords = ['missing-values', 'handling', 'python'],   # Keywords that define your package best
      install_requires=[            # I get to this in a second
                        'numpy',
                        'pandas',
                        ],
      classifiers=[
                   'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
                   'Intended Audience :: Developers',      # Define that your audience are developers
                   'Topic :: Software Development :: Build Tools',
                   'License :: OSI Approved :: MIT License',   # Again, pick a license
                   'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
                   'Programming Language :: Python :: 3.4',
                   'Programming Language :: Python :: 3.5',
                   'Programming Language :: Python :: 3.6',
                   ],
      )
